Actions, Resources, and Condition Keys for Amazon Elastic Container Registry - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic Container Registry.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Elastic Container Registry

Amazon Elastic Container Registry (service prefix: `ecr`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Elastic Container Registry
- Resources Defined by Amazon Elastic Container Registry
- Condition Keys for Amazon Elastic Container Registry

## Actions Defined by Amazon Elastic Container Registry

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchCheckLayerAvailability | Check the availability of multiple image layers in a specified registry and repository. | Read | repository* |  |
BatchDeleteImage | Deletes a list of specified images within a specified repository. | Write | repository* |  |
BatchGetImage | Gets detailed information for specified images within a specified repository. | Read | repository* |  |
CompleteLayerUpload | Inform Amazon ECR that the image layer upload for a specified registry, repository name, and upload ID, has completed. | Write | repository* |  |
CreateRepository | Creates an image repository. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteLifecyclePolicy | Deletes the specified lifecycle policy. | Write | repository* |  |
DeleteRepository | Deletes an existing image repository. | Write | repository* |  |
DeleteRepositoryPolicy | Deletes the repository policy from a specified repository. | Write | repository* |  |
DescribeImages | Returns metadata about the images in a repository, including image size, image tags, and creation date. | Read | repository* |  |
DescribeRepositories | Describes image repositories in a registry | List | repository |  |
GetAuthorizationToken | Retrieves a token that is valid for a specified registry for 12 hours. | Read |  |  |
GetDownloadUrlForLayer | Retrieves the pre-signed Amazon S3 download URL corresponding to an image layer. | Read | repository* |  |
GetLifecyclePolicy | Retrieves the specified lifecycle policy. | Read | repository* |  |
GetLifecyclePolicyPreview | Retrieves the results of the specified lifecycle policy preview request. | Read | repository* |  |
GetRepositoryPolicy | Retrieves the repository policy for a specified repository. | Read | repository* |  |
InitiateLayerUpload | Notify Amazon ECR that you intend to upload an image layer. | Write | repository* |  |
ListImages | Lists all the image IDs for a given repository. | List | repository* |  |
ListTagsForResource | List the tags for an Amazon ECR resource. | Read | repository* |  |
PutImage | Creates or updates the image manifest associated with an image. | Write | repository* |  |
PutImageTagMutability | Updates the image tag mutability settings for an existing repository. | Write | repository* |  |
PutLifecyclePolicy | Creates or updates a lifecycle policy. | Write | repository* |  |
SetRepositoryPolicy | Applies a repository policy on a specified repository to control access permissions. | Permissions management | repository* |  |
StartLifecyclePolicyPreview | Starts a preview of the specified lifecycle policy. This allows you to see the results before creating the lifecycle policy. | Write | repository* |  |
TagResource | Adds specified tags to a resource with the specified ARN. Existing tags on a resource are not changed if they are not specified in the request parameters. | Tagging | repository* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Deletes specified tags from a resource. | Tagging | repository* |  |
UploadLayerPart | Uploads an image layer part to Amazon ECR. | Write | repository* |  |

## Resources Defined by Amazon Elastic Container Registry

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
repository | `arn:${Partition}:ecr:${Region}:${Account}:repository/${RepositoryName}` | aws:ResourceTag/${TagKey} ecr:ResourceTag/${TagKey}

## Condition Keys for Amazon Elastic Container Registry

Amazon Elastic Container Registry defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the tags. | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String
ecr:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource. | String

On this page:

- Actions Defined by Amazon Elastic Container Registry
- Resources Defined by Amazon Elastic Container Registry
- Condition Keys for Amazon Elastic Container Registry

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more